# Claver - Interactive Message Board
Interactive Message Board for the Raspberry Pi 4 with a touchscreen.

[![PyPi Version](https://img.shields.io/pypi/v/Claver-Message-Board)](https://pypi.python.org/pypi/Claver-Message-Board/)
[![PyPi Version](https://img.shields.io/pypi/wheel/Claver-Message-Board)](https://pypi.python.org/pypi/Claver-Message-Board/)
[![PyPi Version](https://img.shields.io/pypi/implementation/Claver-Message-Board)](https://pypi.python.org/pypi/Claver-Message-Board/)
[![PyPi Version](https://img.shields.io/pypi/pyversions/Claver-Message-Board)](https://pypi.python.org/pypi/Claver-Message-Board/)
### Getting Started
Although this project runs as a stand-alone desktop application, it is designed to be run
on a Raspberry Pi 4 Model B with a 1080p touchscreen monitor.

#### Requirements
* Raspberry Pi 4 running the lastest version of Ubuntu

#### Installing
` pip install Claver-Message-Board`

#### Build Environment
* PyCharm 2020.1
* PyGObject 3.36
* PyCairo 1.19

#### Donations
* [Buy us a Coffee](https://ko-fi.com/mccolmrobotics)

#### License
[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/atomic-design-ui/blob/master/LICENSEs)

This project is licensed under the MIT License - see the LICENSE.md file for details

Copyright 2020 © McColm Robotics